@@ -17,8 +17,8 @@ from neuro_sdk import (
     ImageProgressSave,
     ImageProgressStep,
     RemoteImage,
+    Tag,
 )
-from neuro_sdk.parsing_utils import Tag
 
 from ..utils import format_size
 from .utils import ImageFormatter
@@ -135,7 +135,7 @@ class DetailedDockerImageProgress(DockerImageProgress):
                     layer=layer,
                     description=data.status,
                     completed=current or 0,  # type: ignore
-                    total=total or 100,  # type: ignore
+                    total=total or 100,
                 )
                 self._mapping[layer] = task
 
