@@ -30,7 +30,7 @@ def command(
 
 
 class Group(click.Group):
-    def command(
+    def command(  # type: ignore
         self, *args: Any, **kwargs: Any
     ) -> Callable[[Callable[..., Any]], Command]:
         def decorator(f: Callable[..., Any]) -> Command:
@@ -40,7 +40,7 @@ class Group(click.Group):
 
         return decorator
 
-    def group(
+    def group(  # type: ignore
         self, *args: Any, **kwargs: Any
     ) -> Callable[[Callable[..., Any]], "Group"]:
         def decorator(f: Callable[..., Any]) -> Group:
@@ -448,7 +448,8 @@ async def aliases() -> None:
 
 @topics.command()
 async def secrets() -> None:
-    """Using secrets
+    """\
+    Using secrets
     =============
 
     A *secret* is a piece of encrypted named data stored in the Neuro Platform Cluster.
@@ -496,7 +497,8 @@ async def secrets() -> None:
 
 @topics.command()
 async def sharing() -> None:
-    """Using the sharing functionality
+    """\
+    Using the sharing functionality
     ===============================
 
     Understanding permissions
