@@ -8,6 +8,7 @@ import re
 import shlex
 import shutil
 import sys
+import textwrap
 from datetime import timedelta
 from typing import (
     Any,
@@ -22,6 +23,7 @@ from typing import (
     Tuple,
     Type,
     TypeVar,
+    Union,
     cast,
 )
 
@@ -30,7 +32,7 @@ import humanize
 from aiohttp import ClientResponseError
 from yarl import URL
 
-from neuro_sdk import Action, Client, JobStatus, Volume
+from neuro_sdk import Action, Client, JobStatus, ResourceNotFound, Volume
 
 from .parse_utils import parse_timedelta
 from .root import Root
@@ -196,7 +198,9 @@ class NeuroClickMixin:
         """Writes the help text to the formatter if it exists."""
         deprecated = self.deprecated  # type: ignore
         help = self.help  # type: ignore
+        help = help and textwrap.dedent(help)
         if help:
+            help = inspect.cleandoc(help).partition("\f")[0]
             help_text, *examples = split_examples(help)
             if help_text:
                 formatter.write_paragraph()
@@ -301,7 +305,7 @@ def command(
 
 
 class Group(NeuroGroupMixin, click.Group):
-    def command(
+    def command(  # type: ignore
         self, *args: Any, **kwargs: Any
     ) -> Callable[[Callable[..., Any]], Command]:
         def decorator(f: Callable[..., Any]) -> Command:
@@ -311,9 +315,9 @@ class Group(NeuroGroupMixin, click.Group):
 
         return decorator
 
-    def group(
+    def group(  # type: ignore
         self, *args: Any, **kwargs: Any
-    ) -> Callable[[Callable[..., Any]], "Group"]:
+    ) -> Callable[[Callable[..., Any]], "Group"]:  # ignore
         def decorator(f: Callable[..., Any]) -> Group:
             cmd = group(*args, **kwargs)(f)
             self.add_command(cmd)
@@ -430,6 +434,7 @@ async def resolve_job_ex(
 ) -> Tuple[str, str]:
     default_user = client.username
     default_cluster = client.cluster_name
+    default_org = client.config.org_name
     if id_or_name_or_uri.startswith("job:"):
         uri = client.parse.str_to_uri(
             id_or_name_or_uri,
@@ -437,14 +442,26 @@ async def resolve_job_ex(
         )
         assert uri.host
         cluster_name = uri.host
-        owner, _, id_or_name = uri.path.lstrip("/").partition("/")
-        if not owner:
-            raise ValueError("Invalid job URI: missing owner")
-        if not id_or_name:
-            raise ValueError("Invalid job URI: missing job-id or job-name")
+        owner, _, id_or_name = uri.path.lstrip("/").rpartition("/")
+        owners: Dict[str, Optional[str]] = {}
+        if "/" not in owner:
+            owners[owner] = None
+        elif default_org and owner.startswith(default_org + "/"):
+            org_name, _, owner = owner.partition("/")
+            owners[owner] = org_name
+        elif owner == default_user or owner.startswith(default_user + "/"):
+            owners[owner] = None
+        else:
+            owners[owner] = None
+            org_name, _, owner = owner.partition("/")
+            owners[owner] = org_name
+
+        if not id_or_name or not owner:
+            raise ValueError(f"Invalid job URI: {uri!s}")
     else:
         id_or_name = id_or_name_or_uri
         owner = default_user
+        owners = {default_user: default_org}
         cluster_name = default_cluster
 
     # Temporary fast path.
@@ -454,20 +471,20 @@ async def resolve_job_ex(
     try:
         async with client.jobs.list(
             name=id_or_name,
-            owners={owner},
+            owners=owners.keys(),
             reverse=True,
-            limit=1,
             cluster_name=cluster_name,
         ) as it:
             async for job in it:
-                log.debug(f"Job name '{id_or_name}' resolved to job ID '{job.id}'")
-                return job.id, cluster_name
+                if job.owner in owners and job.org_name == owners[job.owner]:
+                    log.debug(f"Job name '{id_or_name}' resolved to job ID '{job.id}'")
+                    return job.id, cluster_name
     except asyncio.CancelledError:
         raise
     except ClientResponseError as e:
         log.error(
             f"Failed to resolve job-name {id_or_name_or_uri} resolved as "
-            f"name={id_or_name}, owner={owner} to a job-ID: {e}"
+            f"name={id_or_name}, owners={owners} to a job-ID: {e}"
         )
 
     if owner != default_user:
@@ -479,13 +496,34 @@ DISK_ID_PATTERN = r"disk-[0-9a-z]{8}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z]{4}-[0-9a-z
 
 
 async def resolve_disk(
-    id_or_name: str, *, client: Client, cluster_name: Optional[str] = None
+    id_or_name_or_uri: Union[str, URL],
+    *,
+    client: Client,
+    cluster_name: Optional[str] = None,
 ) -> str:
+    if isinstance(id_or_name_or_uri, URL):
+        id_or_name = id_or_name_or_uri.parts[-1]
+    else:
+        id_or_name = id_or_name_or_uri
     # Temporary fast path.
     if re.fullmatch(DISK_ID_PATTERN, id_or_name):
         return id_or_name
 
-    disk = await client.disks.get(id_or_name, cluster_name)
+    if isinstance(id_or_name_or_uri, URL):
+        cluster_name = id_or_name_or_uri.host
+        possible_owners = [
+            "/".join(id_or_name_or_uri.parts[1:-1]),
+            "/".join(id_or_name_or_uri.parts[2:-1]),
+        ]
+        for owner in possible_owners:
+            try:
+                disk = await client.disks.get(id_or_name, cluster_name, owner=owner)
+                return disk.id
+            except ResourceNotFound:
+                pass
+        raise ValueError(f"Failed to resolve job {id_or_name_or_uri}")
+    else:
+        disk = await client.disks.get(id_or_name, cluster_name)
     return disk.id
 
 
@@ -531,7 +569,7 @@ async def resolve_bucket_credential(
     return credential.id
 
 
-SHARE_SCHEMES = ("storage", "image", "job", "blob", "role", "secret", "disk")
+SHARE_SCHEMES = ("storage", "image", "job", "blob", "role", "secret", "disk", "flow")
 
 
 def parse_resource_for_sharing(uri: str, root: Root) -> URL:
