@@ -31,33 +31,33 @@ def test_parse_memory() -> None:
     assert parse_memory("1kb") == 1000
     assert parse_memory("2kb") == 2000
 
-    assert parse_memory("42M") == 42 * 1024 ** 2
-    assert parse_memory("42MB") == 42 * 1000 ** 2
-    assert parse_memory("42Mb") == 42 * 1000 ** 2
+    assert parse_memory("42M") == 42 * 1024**2
+    assert parse_memory("42MB") == 42 * 1000**2
+    assert parse_memory("42Mb") == 42 * 1000**2
 
-    assert parse_memory("42G") == 42 * 1024 ** 3
-    assert parse_memory("42GB") == 42 * 1000 ** 3
-    assert parse_memory("42Gb") == 42 * 1000 ** 3
+    assert parse_memory("42G") == 42 * 1024**3
+    assert parse_memory("42GB") == 42 * 1000**3
+    assert parse_memory("42Gb") == 42 * 1000**3
 
-    assert parse_memory("42T") == 42 * 1024 ** 4
-    assert parse_memory("42TB") == 42 * 1000 ** 4
-    assert parse_memory("42Tb") == 42 * 1000 ** 4
+    assert parse_memory("42T") == 42 * 1024**4
+    assert parse_memory("42TB") == 42 * 1000**4
+    assert parse_memory("42Tb") == 42 * 1000**4
 
-    assert parse_memory("42P") == 42 * 1024 ** 5
-    assert parse_memory("42PB") == 42 * 1000 ** 5
-    assert parse_memory("42Pb") == 42 * 1000 ** 5
+    assert parse_memory("42P") == 42 * 1024**5
+    assert parse_memory("42PB") == 42 * 1000**5
+    assert parse_memory("42Pb") == 42 * 1000**5
 
-    assert parse_memory("42E") == 42 * 1024 ** 6
-    assert parse_memory("42EB") == 42 * 1000 ** 6
-    assert parse_memory("42Eb") == 42 * 1000 ** 6
+    assert parse_memory("42E") == 42 * 1024**6
+    assert parse_memory("42EB") == 42 * 1000**6
+    assert parse_memory("42Eb") == 42 * 1000**6
 
-    assert parse_memory("42Z") == 42 * 1024 ** 7
-    assert parse_memory("42ZB") == 42 * 1000 ** 7
-    assert parse_memory("42Zb") == 42 * 1000 ** 7
+    assert parse_memory("42Z") == 42 * 1024**7
+    assert parse_memory("42ZB") == 42 * 1000**7
+    assert parse_memory("42Zb") == 42 * 1000**7
 
-    assert parse_memory("42Y") == 42 * 1024 ** 8
-    assert parse_memory("42YB") == 42 * 1000 ** 8
-    assert parse_memory("42Yb") == 42 * 1000 ** 8
+    assert parse_memory("42Y") == 42 * 1024**8
+    assert parse_memory("42YB") == 42 * 1000**8
+    assert parse_memory("42Yb") == 42 * 1000**8
 
 
 def test_parse_ps_columns_default() -> None:
@@ -90,7 +90,7 @@ def test_parse_ps_columns_partial() -> None:
     ci = PS_COLUMNS_MAP["description"]
     assert parse_ps_columns("{DESC}") == [
         JobColumnInfo(
-            "description", ci.title, ci.justify, ci.width, ci.min_width, ci.max_width
+            "desc", ci.title, ci.justify, ci.width, ci.min_width, ci.max_width
         )
     ]
 
@@ -149,6 +149,36 @@ def test_parse_ps_columns_props_width() -> None:
     ]
 
 
+def test_parse_ps_columns_multi_id() -> None:
+    ci1 = PS_COLUMNS_MAP["id"]
+    ci2 = PS_COLUMNS_MAP["name"]
+    assert ci1.width is not None
+    assert ci1.max_width is None
+    assert ci2.width is None
+    assert ci2.max_width is not None
+    expected = [
+        JobColumnInfo(
+            "id/name", "ID/NAME", ci1.justify, ci1.width, None, ci2.max_width + 1
+        )
+    ]
+    assert parse_ps_columns("id/name") == expected
+    assert parse_ps_columns("{id/name}") == expected
+    assert parse_ps_columns("{id/name;ID/NAME}") == expected
+    expected = [
+        JobColumnInfo(
+            "name/id", "NAME/ID", ci2.justify, ci1.width + 1, None, ci2.max_width
+        )
+    ]
+    assert parse_ps_columns("name/id") == expected
+
+
+def test_parse_ps_columns_multi_id_props_full() -> None:
+    ci1 = PS_COLUMNS_MAP["id"]
+    assert parse_ps_columns("{id/name;max=30;min=5;align=center;Id (Name)}") == [
+        JobColumnInfo("id/name", "Id (Name)", "center", ci1.width, 5, 30)
+    ]
+
+
 def test_parse_ps_columns_invalid_format() -> None:
     with pytest.raises(ValueError, match="Invalid format"):
         parse_ps_columns("{id")
